summaryrefslogtreecommitdiff
path: root/include/functions.php
diff options
context:
space:
mode:
Diffstat (limited to 'include/functions.php')
-rw-r--r--include/functions.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/functions.php b/include/functions.php
index 4d11ea31f..5e75439cf 100644
--- a/include/functions.php
+++ b/include/functions.php
@@ -2,8 +2,8 @@
define('LABEL_BASE_INDEX', -1024);
define('PLUGIN_FEED_BASE_INDEX', -128);
- /** constant is @deprecated, use Db_Updater::SCHEMA_VERSION instead */
- define('SCHEMA_VERSION', Db_Updater::SCHEMA_VERSION);
+ /** constant is @deprecated, use Config::SCHEMA_VERSION instead */
+ define('SCHEMA_VERSION', Config::SCHEMA_VERSION);
if (version_compare(PHP_VERSION, '8.0.0', '<')) {
libxml_disable_entity_loader(true);